//-----------------------------------------------------------------------
// <copyright file="ExampleTests.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// <summary>Example tests for WiX</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Tools.WindowsInstallerXml.Test.Tests.Examples
{
    using System;
    using System.Collections;
    using System.Collections.Generic;
    using System.IO;
    using System.Text;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// Example tests for WiX
    /// </summary>
    [TestClass]
    public class ExampleTests
    {
        [TestMethod]
        [Description("An example test that verifies an ICE violation is caught by smoke")]
        [Priority(3)]
        public void ExampleTest1()
        {
            string testDirectory = Environment.ExpandEnvironmentVariables(@"%WIX%\test\data\Examples\ExampleTest1");

            // Build the MSI that will be run against Smoke.
            // Pass the -sval argument so that light does not fail due to ICE violations - it will be up to Smoke to catch them.
            string msi = Builder.BuildPackage(testDirectory, "product.wxs", "product.msi", false, null, "-sval");

            // Run Smoke
            Smoke smoke = new Smoke();
            smoke.DatabaseFiles.Add(msi);
            smoke.CubFiles.Add(@"%WIX%\test\data\Examples\ExampleTest1\test.cub");
            smoke.ExpectedWixMessages.Add(new WixMessage(1076, "ICE1000: Component 'ExtraICE.0.ProductComponent' installs into directory 'TARGETDIR', which will get installed into the volume with the most free space unless explicitly set.", WixMessage.MessageTypeEnum.Warning));
            smoke.Run();
        }

        [TestMethod]
        [Description("An example test that verifies an MSI is built correctly")]
        [Priority(3)]
        public void ExampleTest2()
        {
            string actualMSI = Builder.BuildPackage(WixTests.SharedAuthoringDirectory, "BasicProduct.wxs", "BasicProduct.msi", false);
            string expectedMSI = Path.Combine(WixTests.SharedBaselinesDirectory, @"MSIs\BasicProduct.msi");

            Verifier.VerifyResults(expectedMSI, actualMSI);
        }

        [TestMethod]
        [Description("An example test that queries the MSI for a particular value")]
        [Priority(3)]
        public void ExampleTest3()
        {
            Candle candle = new Candle();
            candle.SourceFiles.Add(Path.Combine(WixTests.SharedAuthoringDirectory, "BasicProduct.wxs"));
            candle.Run();

            Light light = new Light(candle);
            light.OutputFile = "test.msi";
            light.Run();
            
            string query = "SELECT `Component_` FROM `File` WHERE `File` = 'Test_txt1'";
            string queryResult = Verifier.Query(light.OutputFile, query);

            Assert.AreEqual("Component1", queryResult);
        }
    }
}
